@@ -1,6 +1,7 @@
-__version__ = "1.1.3"
-
+__version__ = "1.3.0"
 
 from .Scale import Scale
-from .ScaleWithYoloAnnotation import ScaleWithYoloAnnotation
-from .ScaleWithPolyAnnotation import ScaleWithPolyAnnotation
\ No newline at end of file
+from .ScaleWithPolyAnnotation import ScaleWithPolyAnnotation
+from .ScaleWithPolyAnnotation import ScaleWithPolyAnnotation
+from .ScaleWithInverse import ScaleWithInverse
+from .ScaleWithPaddingMap import ScaleWithPaddingMap
